<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr-CS" sourcelanguage="en">
  <context>
    <name>CmdApproxCylinder</name>
    <message>
      <location filename="../../Command.cpp" line="248"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="249"/>
      <source>Cylinder</source>
      <translation>Valjak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="250"/>
      <source>Approximate a cylinder</source>
      <translation>Aproksimiraj valjak</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPlane</name>
    <message>
      <location filename="../../Command.cpp" line="140"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="141"/>
      <source>Plane</source>
      <translation>Ravan</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="142"/>
      <source>Approximate a plane</source>
      <translation>Aproksimiraj ravan</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxPolynomial</name>
    <message>
      <location filename="../../Command.cpp" line="364"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="365"/>
      <source>Polynomial surface</source>
      <translation>Polinomska površina</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="366"/>
      <source>Approximate a polynomial surface</source>
      <translation>Aproksimiraj polinomsku površinu</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSphere</name>
    <message>
      <location filename="../../Command.cpp" line="316"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="317"/>
      <source>Sphere</source>
      <translation>Lopta</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="318"/>
      <source>Approximate a sphere</source>
      <translation>Aproksimiraj loptu</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="102"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="103"/>
      <source>Approximate B-spline surface...</source>
      <translation>Aproksimiraj B-splajn površinu...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="104"/>
      <source>Approximate a B-spline surface</source>
      <translation>Aproksimiraj B-splajn površinu</translation>
    </message>
  </context>
  <context>
    <name>CmdMeshBoundary</name>
    <message>
      <location filename="../../Command.cpp" line="536"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="537"/>
      <source>Wire from mesh boundary...</source>
      <translation>Žičani ram od ivica mreže...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="538"/>
      <source>Create wire from mesh boundaries</source>
      <translation>Napravi žičani ram od ivica mreže</translation>
    </message>
  </context>
  <context>
    <name>CmdPoissonReconstruction</name>
    <message>
      <location filename="../../Command.cpp" line="603"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="604"/>
      <source>Poisson...</source>
      <translation>Poason...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="605"/>
      <source>Poisson surface reconstruction</source>
      <translation>Poasonova rekonstrukcija površine</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentation</name>
    <message>
      <location filename="../../Command.cpp" line="422"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="423"/>
      <source>Mesh segmentation...</source>
      <translation>Segmentacija mreže...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="424"/>
      <source>Create mesh segments</source>
      <translation>Napravi segmente mreže</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationFromComponents</name>
    <message>
      <location filename="../../Command.cpp" line="484"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="485"/>
      <source>From components</source>
      <translation>Od komponenti</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="486"/>
      <source>Create mesh segments from components</source>
      <translation>Napravi segmente mreže od komponenti</translation>
    </message>
  </context>
  <context>
    <name>CmdSegmentationManual</name>
    <message>
      <location filename="../../Command.cpp" line="454"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="455"/>
      <source>Manual segmentation...</source>
      <translation>Ručna segmentacija...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="456"/>
      <source>Create mesh segments manually</source>
      <translation>Napravi segmente mreže ručno</translation>
    </message>
  </context>
  <context>
    <name>CmdViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="638"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="639"/>
      <source>Structured point clouds</source>
      <translation>Strukturirani oblaci tačaka</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="640"/>
      <location filename="../../Command.cpp" line="641"/>
      <source>Triangulation of structured point clouds</source>
      <translation>Triangulacija strukturiranih oblaka tačaka</translation>
    </message>
  </context>
  <context>
    <name>Command</name>
    <message>
      <location filename="../../Command.cpp" line="226"/>
      <source>Fit plane</source>
      <translation>Uklopi ravan</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="258"/>
      <source>Fit cylinder</source>
      <translation>Uklopi valjak</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="326"/>
      <source>Fit sphere</source>
      <translation>Uklopi loptu</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="375"/>
      <source>Fit polynomial surface</source>
      <translation>Uklopi polinomsku površinu</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="650"/>
      <source>View triangulation</source>
      <translation>Prikaz triangulacije</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="154"/>
      <source>Placement</source>
      <translation>Položaj</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="231"/>
      <location filename="../../FitBSplineCurve.cpp" line="139"/>
      <source>Fit B-spline</source>
      <translation>Uklopi B-Splajn</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="83"/>
      <source>Poisson reconstruction</source>
      <translation>Poasonova rekonstrukcija</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.cpp" line="281"/>
      <source>Segmentation</source>
      <translation>Segmentacija</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurface</name>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>Uklopi B-Splajn površinu</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="20"/>
      <source>u-Direction</source>
      <translation>u-smer</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="26"/>
      <location filename="../../FitBSplineSurface.ui" line="93"/>
      <source>Degree</source>
      <translation>Stepeni</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="55"/>
      <location filename="../../FitBSplineSurface.ui" line="122"/>
      <source>Control points</source>
      <translation>Kontrolne tačke</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="87"/>
      <source>v-Direction</source>
      <translation>v-smer</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="154"/>
      <source>Settings</source>
      <translation>Podešavanja</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="160"/>
      <source>Iterations</source>
      <translation>Iteracije</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="189"/>
      <source>Size factor</source>
      <translation>Koeficijent veličine</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="218"/>
      <source>User-defined u/v directions</source>
      <translation>Kirisnički definisani u/v smerovi</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="231"/>
      <source>Create placement</source>
      <translation>Napravi položaj</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="238"/>
      <source>Smoothing</source>
      <translation>Glačanje</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="247"/>
      <source>Total Weight</source>
      <translation>Ukupna Težina</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="276"/>
      <source>Length of gradient</source>
      <translation>Dužina gradijenta</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="305"/>
      <source>Bending energy</source>
      <translation>Energija savijanja</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.ui" line="334"/>
      <source>Curvature variation</source>
      <translation>Promena zakrivljenosti</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineSurfaceWidget</name>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="165"/>
      <location filename="../../FitBSplineSurface.cpp" line="238"/>
      <source>Input error</source>
      <translation>Greška pri unosu</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="206"/>
      <source>Wrong selection</source>
      <translation>Pogrešan izbor</translation>
    </message>
    <message>
      <location filename="../../FitBSplineSurface.cpp" line="207"/>
      <source>Please select a single placement object to get local orientation.</source>
      <translation>Izaberi jedan objekat Položaj da bi dobio lokalnu orijentaciju.</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::PoissonWidget</name>
    <message>
      <location filename="../../Poisson.ui" line="14"/>
      <source>Poisson</source>
      <translation>Poason</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="20"/>
      <source>Parameters</source>
      <translation>Parametri</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="26"/>
      <source>Octree depth</source>
      <translation>Dubina oktalnog stabla</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="46"/>
      <source>Solver divide</source>
      <translation>Solver podela</translation>
    </message>
    <message>
      <location filename="../../Poisson.ui" line="66"/>
      <source>Samples per node</source>
      <translation>Broj diskretnih elemenata po čvoru</translation>
    </message>
    <message>
      <location filename="../../Poisson.cpp" line="90"/>
      <source>Input error</source>
      <translation>Greška pri unosu</translation>
    </message>
  </context>
  <context>
    <name>Reen_ApproxSurface</name>
    <message>
      <location filename="../../Command.cpp" line="82"/>
      <location filename="../../Command.cpp" line="120"/>
      <location filename="../../Command.cpp" line="618"/>
      <source>Wrong selection</source>
      <translation>Pogrešan izbor</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="83"/>
      <source>Please select a point cloud.</source>
      <translation>Izaberi oblak tačaka.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="121"/>
      <source>Please select a point cloud or mesh.</source>
      <translation>Izaberi oblak tačaka ili mrežu.</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="619"/>
      <source>Please select a single point cloud.</source>
      <translation>Izaberi jedan oblak tačaka.</translation>
    </message>
  </context>
  <context>
    <name>Reen_ViewTriangulation</name>
    <message>
      <location filename="../../Command.cpp" line="672"/>
      <source>View triangulation failed</source>
      <translation>Prikaz triangulacije nije uspeo</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::Segmentation</name>
    <message>
      <location filename="../../Segmentation.ui" line="14"/>
      <source>Mesh segmentation</source>
      <translation>Segmentacija mreže</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="20"/>
      <source>Smooth mesh</source>
      <translation>Glatka mreža</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="37"/>
      <source>Plane</source>
      <translation>Ravan</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="46"/>
      <source>Curvature tolerance</source>
      <translation>Tolerancija zakrivljenosti</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="63"/>
      <source>Distance to plane</source>
      <translation>Udaljenost do ravni</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="80"/>
      <source>Minimum number of faces</source>
      <translation>Minimalni broj stranica</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="100"/>
      <source>Create mesh from unused triangles</source>
      <translation>Napravi mrežu od neiskorišćenih trouglova</translation>
    </message>
    <message>
      <location filename="../../Segmentation.ui" line="107"/>
      <source>Create compound</source>
      <translation>Napravi sastavljeni objekat</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::SegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.ui" line="14"/>
      <source>Manual segmentation</source>
      <translation>Ručna segmentacija</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="20"/>
      <source>Select</source>
      <translation>Izaberi</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="41"/>
      <source>Region</source>
      <translation>Region</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="61"/>
      <source>All</source>
      <translation>Svi</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="81"/>
      <source>Components</source>
      <translation>Komponente</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="88"/>
      <source>&lt; faces than</source>
      <translation>&lt; stranica od</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="98"/>
      <source>Pick triangle</source>
      <translation>Izaberi trougao</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="105"/>
      <source>Select whole component</source>
      <translation>Izaberi celu komponentu</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="112"/>
      <source>Clear</source>
      <translation>Obriši</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="122"/>
      <source>Plane</source>
      <translation>Ravan</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="128"/>
      <location filename="../../SegmentationManual.ui" line="181"/>
      <location filename="../../SegmentationManual.ui" line="234"/>
      <source>Detect</source>
      <translation>Otkrij</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="135"/>
      <location filename="../../SegmentationManual.ui" line="188"/>
      <location filename="../../SegmentationManual.ui" line="241"/>
      <source>Tolerance</source>
      <translation>Tolerancija</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="155"/>
      <location filename="../../SegmentationManual.ui" line="208"/>
      <location filename="../../SegmentationManual.ui" line="261"/>
      <source>Minimum number of faces</source>
      <translation>Minimalni broj stranica</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="175"/>
      <source>Cylinder</source>
      <translation>Valjak</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="228"/>
      <source>Sphere</source>
      <translation>Lopta</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="281"/>
      <source>Region options</source>
      <translation>Parametri regiona</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="287"/>
      <source>Respect only visible triangles</source>
      <translation>Uvaži samo vidljive trouglove</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="297"/>
      <source>Respect only triangles with normals facing screen</source>
      <translation>Uvažite samo trouglove sa normalama okrenutim prema ekranu</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="310"/>
      <source>Segmentation</source>
      <translation>Segmentacija</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="316"/>
      <source>Cut segment from mesh</source>
      <translation>Iseci segment od mreže</translation>
    </message>
    <message>
      <location filename="../../SegmentationManual.ui" line="326"/>
      <source>Hide segment</source>
      <translation>Sakrij segment</translation>
    </message>
  </context>
  <context>
    <name>ReverseEngineeringGui::TaskSegmentationManual</name>
    <message>
      <location filename="../../SegmentationManual.cpp" line="352"/>
      <source>Create</source>
      <translation>Spakuj</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="34"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineCurve</name>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="14"/>
      <source>Fit B-spline surface</source>
      <translation>Uklopi B-Splajn površinu</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="20"/>
      <source>Parameters</source>
      <translation>Parametri</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="26"/>
      <source>Maximum degree</source>
      <translation>Maksimalni stepen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="37"/>
      <source>Chord length</source>
      <translation>Dužina tetive</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="42"/>
      <source>Centripetal</source>
      <translation>Centripetalni</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="47"/>
      <source>Iso-Parametric</source>
      <translation>Iso-Parametarski</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="55"/>
      <source>Continuity</source>
      <translation>Kontinualnost</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="88"/>
      <source>Parametrization type</source>
      <translation>Vrsta parametrizacije</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="96"/>
      <source>C0</source>
      <translation>C0</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="101"/>
      <source>G1</source>
      <translation>G1</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="106"/>
      <source>C1</source>
      <translation>C1</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="111"/>
      <source>G2</source>
      <translation>G2</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="116"/>
      <source>C2</source>
      <translation>C2</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="121"/>
      <source>C3</source>
      <translation>C3</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="126"/>
      <source>CN</source>
      <translation>CN</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="134"/>
      <source>Minimum degree</source>
      <translation>Minimalni stepen</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="141"/>
      <source>Closed curve</source>
      <translation>Zatvorena kriva</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="151"/>
      <source>Smoothing</source>
      <translation>Glačanje</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="160"/>
      <source>Torsion</source>
      <translation>Uvijanje</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="167"/>
      <source>Curve length</source>
      <translation>Dužina krive</translation>
    </message>
    <message>
      <location filename="../../FitBSplineCurve.ui" line="174"/>
      <source>Curvature</source>
      <translation>Zakrivljenost</translation>
    </message>
  </context>
  <context>
    <name>CmdApproxCurve</name>
    <message>
      <location filename="../../Command.cpp" line="69"/>
      <source>Reverse Engineering</source>
      <translation>Obrnuti inženjering</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="70"/>
      <source>Approximate B-spline curve...</source>
      <translation>Aproksimiraj B-splajn krivu...</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="71"/>
      <source>Approximate a B-spline curve</source>
      <translation>Aproksimiraj B-splajn krivu</translation>
    </message>
  </context>
  <context>
    <name>ReenGui::FitBSplineCurveWidget</name>
    <message>
      <location filename="../../FitBSplineCurve.cpp" line="91"/>
      <source>Input error</source>
      <translation>Greška pri unosu</translation>
    </message>
  </context>
</TS>
